-- 
-- Worklight LS17
-- version: 1.0
-- date: 30.10.2016
-- last update: -
-- author: [FSM]Chefkoch
-- hp: http://fsm-team.de
-- 
-- Keine Veränderung ohne meine Erlaubnis!
-- No modification without	my permission!
--
-- History:
-- v1:		project started

workLight = {};

function workLight.prerequisitesPresent(specializations)
    return true;
end;

function workLight:load(savegame)
	self.setWorkLight = SpecializationUtil.callSpecializationsFunction("setWorkLight");
	self.wl = {};
	self.wl.rl = Utils.indexToObject(self.components, getXMLString(self.xmlFile, "vehicle.worklight#realLight"));
	self.wl.co = Utils.indexToObject(self.components, getXMLString(self.xmlFile, "vehicle.worklight#corona"));
	self.wl.turnOn = false;
	self.wl.isOn = false;
	self.wl.active = false;
	setVisibility( self.wl.rl, false );
	setVisibility( self.wl.co, false );
	
	WorkLightSoundFile = Utils.getFilename("Sounds/blinktick.wav", self.baseDirectory);
	self.WorkLightSoundId = createSample("WorkLightSound");
	loadSample(self.WorkLightSoundId, WorkLightSoundFile, false);
	self.WorkLightSoundPlaying = false;
	
end;

function workLight:delete()
end;

function workLight:readStream(streamId, connection)
	local state = streamReadBool(streamId);
	self:setWorkLight(state, true);
end;

function workLight:writeStream(streamId, connection)
	streamWriteBool(streamId, self.wl.turnOn);
end;

function workLight:readUpdateStream(streamId, timestamp, connection)
end;

function workLight:writeUpdateStream(streamId, connection, dirtyMask)
end;

function workLight:mouseEvent(posX, posY, isDown, isUp, button)
end;

function workLight:keyEvent(unicode, sym, modifier, isDown)
end;

function workLight:update(dt)
	if self:getIsActive() then
		if self.isClient and self:getIsActiveForInput(false) and not self:hasInputConflictWithSelection() then
			if InputBinding.hasEvent(InputBinding.SWITHWORKLIGHT) then
				self:setWorkLight(not self.wl.turnOn);
				playSample(self.WorkLightSoundId,1,0.5,0);
			end;
		end;
	end;
	
	local realLightsActive = false;
	realLightsActive = self:getIsActiveForLights();
	
	if (self.wl.turnOn == true and self.wl.isOn == false) or (self.wl.active ~= realLightsActive) then
		if self.wl.rl ~= nil then
			if realLightsActive then
				setVisibility( self.wl.rl, true );
			else
				setVisibility( self.wl.rl, false );
			end
		end;
		if self.wl.co ~= nil then
			setVisibility( self.wl.co, true );			
		end;
		self.wl.active = realLightsActive;
		self.wl.isOn = true;
	elseif (self.wl.turnOn == false and self.wl.isOn == true) then
		if self.wl.rl ~= nil then
			setVisibility( self.wl.rl, false );
		end;
		if self.wl.be ~= nil then
			setVisibility( self.wl.be, false );
		end;
		if self.wl.co ~= nil then
			setVisibility( self.wl.co, false );		
		end;
		self.wl.isOn = false;
	end;
end;

function workLight:updateTick(dt)

end;

function workLight:draw()
	if g_currentMission.controlledVehicle ~= nil then
		g_currentMission:addHelpButtonText(g_i18n:getText("WORKLIGHTONOFF"), InputBinding.SWITHWORKLIGHT);
	end;
end;

function workLight:onLeave()

end;

function workLight:onEnter()

end;

function workLight:setWorkLight(state, noEventSend)
	SetWorkLightEvent.sendEvent(self, state, noEventSend);
	self.wl.turnOn = state;
end;
	
	
	
--
--
--
--
--
SetWorkLightEvent = {};
SetWorkLightEvent_mt = Class(SetWorkLightEvent, Event);

InitEventClass(SetWorkLightEvent, "SetWorkLightEvent");

function SetWorkLightEvent:emptyNew()
    local self = Event:new(SetWorkLightEvent_mt);
    self.className="SetWorkLightEvent";
    return self;
end;

function SetWorkLightEvent:new(object, state)
    local self = SetWorkLightEvent:emptyNew()
    self.object = object;
	self.state = state;
    return self;
end;

function SetWorkLightEvent:readStream(streamId, connection)
    local id = streamReadInt32(streamId);
    self.object = networkGetObject(id);
	self.state = streamReadBool(streamId);
    self:run(connection);
end;

function SetWorkLightEvent:writeStream(streamId, connection)
    streamWriteInt32(streamId, networkGetObjectId(self.object));
	streamWriteBool(streamId, self.state);
end;

function SetWorkLightEvent:run(connection)
    self.object:setWorkLight(self.state, true);
    if not connection:getIsServer() then
        g_server:broadcastEvent(SetWorkLightEvent:new(self.object, self.state), nil, connection, self.object);
    end;
end;

function SetWorkLightEvent.sendEvent(vehicle, state, noEventSend)
	if noEventSend == nil or noEventSend == false then
		if g_server ~= nil then
			g_server:broadcastEvent(SetWorkLightEvent:new(vehicle, state), nil, nil, vehicle);
		else
			g_client:getServerConnection():sendEvent(SetWorkLightEvent:new(vehicle, state));
		end;
	end;
end;

